@@ -28,7 +28,8 @@ public:
                 ServizioPubblico,
                 DiTv,
                 Telecupole,
-                Vauro
+                Vauro,
+                Rete8
                };
     void openPage(Browser::Pages page);
     void openPage(QString url);
