@@ -306,3 +306,17 @@ void PuntateMain::on_stream19_clicked()
     process.start("sh /opt/serviziopubblico/script/p19.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down20_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d20.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream20_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p20.sh");
+    process.waitForFinished();
+}
