@@ -96,6 +96,10 @@ private slots:
 
     void on_stream19_clicked();
 
+    void on_down20_clicked();
+
+    void on_stream20_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
